<?php
namespace Claromentis\Mailgun\Model;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array("_a1e707d02" . "a236dadebd" . "15a45e65eb" . "db6" => base64_decode("YXR0YWNo" . "bWVudC1j" . "b3VudA=="), "_618a4aeb9fecc4592a4" . "521f34876fa29" => base64_decode("ZnJvbQ" . "=="), "_956cd32298a229f9768f1096f077ace" . "3" => base64_decode("Ym9keS1w" . "bGFpbg=="), "_9c050c786fc87170cbb84fc6" . "a8b13cb6" => base64_decode("YXR0YWNobWVudC0" . "="), "_97ea09a7faf27c52c6eff69773df1d8" . "a" => base64_decode("dGl" . "tZX" . "N0Y" . "W1w"), "_1d6c68a0262e8fa0bed121" . "5b7224a98e" => base64_decode("cmVjaXB" . "pZW50"), "_f589476007fa133f457c" . "3ef29ddfa566" => base64_decode("VG" . "8="), "_6e1c717cf3cbf1af982ed74d4336b7" . "f1" => base64_decode("Ym9keS1od" . "G1s"), "_d706c160e45bf7434fff" . "82a5976f0e19" => base64_decode("YXJyY" . "Xlfa2" . "V5cw=" . "="), "_44e986c04f41a08b56a383c7b3a" . "88ee2" => base64_decode("c2Vu" . "ZGVy"), "_f39f5346e31" . "3e4dd1ac3a7b" . "d8032beda" => base64_decode("c3Vic3RyX2NvbXB" . "hcmU="), "_8c575917cbae" . "df1e7efae8493" . "9402bff" => base64_decode("U3ViamVjd" . "A=="));
use Claromentis\Core\Mail\Receive\Contract\MailAttachment;
use Claromentis\Core\Mail\Receive\Contract\MailMessage;
use Claromentis\Core\Util\ArrayUtil;




class MailgunMessage implements MailMessage
{
    protected $message_data;
    protected $attachments_data;
    protected $attachments;
    
    
    
    
    
    public function __construct($_a3d82c5df38e194c9c73e3ccb4223bbc = [], $_4e7ab34a53ffb13eb0838003f33034d4 = [])
    {
        $this->message_data = $_a3d82c5df38e194c9c73e3ccb4223bbc;
        $this->attachments = $_4e7ab34a53ffb13eb0838003f33034d4;
        foreach ($GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"]["_d706c160e45bf7434fff82a5976f0" . "e19"]($this->message_data) as $key) {
            if ($key !== $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_a1e707d02a236dadebd15a45" . "e65ebdb6"] && $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_f39f5346e313e4dd1" . "ac3a7bd8032beda"]($key, $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_9c050c786fc87170cbb84fc6a" . "8b13cb6"], 0, 11) === 0) {
                $this->attachments[] = new MailgunAttachmentString($key, $this->message_data[$key]);
            }
        }
    }
    
    
    
    
    public function GetRecipientAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_1d6c68a026" . "2e8fa0bed12" . "15b7224a98e"]);
    }
    
    
    
    
    
    
    public function GetFrom() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_618a4aeb9fecc4592a452" . "1f34876fa29"]], null);
    }
    
    
    
    
    
    
    
    public function GetTo() : string
    {
        return ArrayUtil::getScalarValue($this->message_data[$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_f589476007f" . "a133f457c3ef" . "29ddfa566"]], null);
    }
    
    
    
    
    public function GetSubject() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_8c575917cbaedf1" . "e7efae84939402bf" . "f"]);
    }
    
    
    
    
    public function GetBodyHtml() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_6e1c717c" . "f3cbf1af9" . "82ed74d43" . "36b7f1"]);
    }
    
    
    
    
    public function GetBodyText() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_956cd32298a229f" . "9768f1096f077ace" . "3"]);
    }
    
    
    
    
    public function GetDate() : \Date
    {
        $_67a0d624aebcceb0abd5ce56a53ff06f = new \Date(ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_97ea09a7faf27c52c6eff69" . "773df1d8a"]));
        return $_67a0d624aebcceb0abd5ce56a53ff06f;
    }
    
    
    
    
    public function GetSenderAddress() : string
    {
        return ArrayUtil::getScalarValue($this->message_data, $GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_44e986c04f41" . "a08b56a383c7b" . "3a88ee2"]);
    }
    public function GetAttachments()
    {
        return $this->attachments;
    }
}