<?php
namespace Claromentis\Infocapture\Subscriber;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array("_67a0d624aeb" . "cceb0abd5ce5" . "6a53ff06f" => base64_decode("ZGF" . "0ZQ" . "=="), "proje" . "ct_id" => base64_decode("cHJvamVjdF9pZA" . "=="), "_376d30c40857357a4d4cbb1ffaa25" . "817" => base64_decode("d" . "G" . "8" . "="), "_c35473364fa7a050" . "299058f332ec29c1" => base64_decode("ZXhjZXB0a" . "W9u"), "_9b16fa2683095e67d7c8b265a" . "8081d0b" => base64_decode("TWFpbFJlY2VpdmVkRXZ" . "lbnRSZWNlaXZlcg=="), "_ced92d7b391285c8a2684" . "6f1f4bd3128" => base64_decode("Ym9keV90" . "ZXh0"), "_a3d82c5df38e194c9" . "c73e3ccb4223bbc" => base64_decode("ZW1haWxfZGF0YQ" . "=="), "_5d40a2cf1c525fb252" . "bf5599e339fdd0" => base64_decode("Tm8gaW5mb2NhcHR1cmUgcHJvamVjdCB3YXMgaWRlbnRpZmllZCBmb3IgbWFpbDsgc3Via" . "mVjdCAn"), "_03b1f0cee835582d115" . "8dce2678b505c" => base64_decode("U3RhcnRpbmcgaW5mb2NhcHR1cmUgbWFpbCByZWNlaXZlZCBzdWJ" . "zY3JpYmVy"), "_f656816961e8" . "573806141c558" . "b184fe2" => base64_decode("c3ViamV" . "jdA=="), "_bfda889b74ea561b14325e30e7" . "d75426" => base64_decode("Ym9keV9odG1" . "s"), "_e608e5b5c4c34a67ba97ef" . "84c1e16199" => base64_decode("Jw" . "=="), "_618a4aeb9f" . "ecc4592a452" . "1f34876fa29" => base64_decode("Zn" . "Jv" . "bQ" . "=="), "_460e1aeb3113a1676ce59" . "a8f40431d5c" => base64_decode("RmFpbGVkIHRvIHByb2Nlc" . "3MgZW1haWwgZm9yIGluZm" . "9jYXB0dXJlIHByb2plY3Q" . "="));
use Claromentis\Core\Event\EventDispatcherInterface;
use Claromentis\Core\Event\EventSubscriberInterface;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEventType;
use Claromentis\Core\Mail\Receive\Event\ReceiveMailEvent;
use Claromentis\Infocapture\Model\MailboxMessage;
use Claromentis\Infocapture\UseCase\GetProjectByEmailAddress;
use Claromentis\Infocapture\UseCase\ProcessEmail;
use Exception;
use Psr\Log\LoggerInterface;
class MailReceivedSubscriber implements EventSubscriberInterface
{
    protected $logger;
    protected $get_project_use_case;
    protected $process_email_use_case;
    public function __construct(LoggerInterface $logger, GetProjectByEmailAddress $_ecd19adac06bcc3637cff9925531a823, ProcessEmail $_33929bbf18079cca22e39e6dbe7eea3c)
    {
        $this->logger = $logger;
        $this->get_project_use_case = $_ecd19adac06bcc3637cff9925531a823;
        $this->process_email_use_case = $_33929bbf18079cca22e39e6dbe7eea3c;
    }
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public static function getSubscribedEvents()
    {
        return [
            
            
            ReceiveMailEventType::RECEIVE_MAIL => $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_9b16fa268" . "3095e67d7c" . "8b265a8081" . "d0b"],
        ];
    }
    
    
    
    
    
    
    public function MailReceivedEventReceiver(ReceiveMailEvent $event, $_5693d84b45564f912e36404cbe8957e8, EventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        $this->logger->info($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_03b1f0c" . "ee835582" . "d1158dce" . "2678b505" . "c"]);
        $_a9bf694098bca136cc65bf4d2623bc70 = $event->GetMailMessage();
        $_f656816961e8573806141c558b184fe2 = $_a9bf694098bca136cc65bf4d2623bc70->GetSubject();
        
        
        $project = null;
        if ($_a9bf694098bca136cc65bf4d2623bc70 instanceof MailboxMessage) {
            $project = $_a9bf694098bca136cc65bf4d2623bc70->GetProject();
        } else {
            $project = $this->get_project_use_case->GetMailgunProject($_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress());
        }
        if ($project === null) {
            $this->logger->debug($GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_5d40a2cf1c525fb252bf5599" . "e339fdd0"] . $_f656816961e8573806141c558b184fe2 . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_e608e5b5c4c34a67" . "ba97ef84c1e16199"]);
            return;
        }
        $_a3d82c5df38e194c9c73e3ccb4223bbc = [$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_618a4aeb9fecc4592a4521f" . "34876fa29"] => $_a9bf694098bca136cc65bf4d2623bc70->GetSenderAddress(), $GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["_376d30c4" . "0857357a4" . "d4cbb1ffa" . "a25817"] => $_a9bf694098bca136cc65bf4d2623bc70->GetRecipientAddress(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_f656816961e8573806141c558" . "b184fe2"] => $_f656816961e8573806141c558b184fe2, $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_ced92d7b391285c8a26846f1f4bd3" . "128"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyText(), $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_bfda889b74ea561b14325e30e7d7" . "5426"] => $_a9bf694098bca136cc65bf4d2623bc70->GetBodyHtml(), $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_67a0d62" . "4aebcceb" . "0abd5ce5" . "6a53ff06" . "f"] => $_a9bf694098bca136cc65bf4d2623bc70->GetDate()];
        try {
            $this->process_email_use_case->ProcessEmail($project, $_a3d82c5df38e194c9c73e3ccb4223bbc, $_a9bf694098bca136cc65bf4d2623bc70->GetAttachments());
        } catch (Exception $_c35473364fa7a050299058f332ec29c1) {
            $this->logger->warning($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_460e1aeb3113a16" . "76ce59a8f40431d5" . "c"], [$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"]["project_" . "id"] => $project->GetId(), $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_a3d82c5df" . "38e194c9c7" . "3e3ccb4223" . "bbc"] => $_a3d82c5df38e194c9c73e3ccb4223bbc, $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_c35473364fa7a050299058f3" . "32ec29c1"] => $_c35473364fa7a050299058f332ec29c1]);
        }
    }
}